==> qxmpp_0.7.3.orig.tar.gz: qxmpp-0.7.3/doc/html/search/all_75.js <==
var searchData=
[
  ['unavailable',['Unavailable',['../classQXmppPresence.html#a47ab8dd08436f9d7c90d2990678b5a6da6188ca67163c9045eb9568deefb9a363',1,'QXmppPresence']]],
  ['unsubscribe',['Unsubscribe',['../classQXmppPresence.html#a47ab8dd08436f9d7c90d2990678b5a6da20986f18e387f68a5fdfa0e67c44bc44',1,'QXmppPresence::Unsubscribe()'],['../classQXmppRosterManager.html#aa743c82ec16b20e1134f994487db1023',1,'QXmppRosterManager::unsubscribe()']]],
  ['unsubscribed',['Unsubscribed',['../classQXmppPresence.html#a47ab8dd08436f9d7c90d2990678b5a6da63414092d2fc4b90987f56731c150623',1,'QXmppPresence']]],
  ['uris',['uris',['../classQXmppDataForm_1_1Media.html#a3b25e4741293aacf49e67763d6335ffa',1,'QXmppDataForm::Media']]],
  ['url',['url',['../classQXmppBookmarkUrl.html#ad4f5f12b7d3abcec0dd39b807bc574e4',1,'QXmppBookmarkUrl::url()'],['../classQXmppVCardIq.html#aece55c4dc1a59328aaa643ec7fddb1ec',1,'QXmppVCardIq::url()']]],
  ['urls',['urls',['../classQXmppBookmarkSet.html#ac670a788961da47538470df0a962417e',1,'QXmppBookmarkSet']]],
  ['usenonsaslauthentication',['useNonSASLAuthentication',['../classQXmppConfiguration.html#aa1fde10dbd102621f412e64cb047a65e',1,'QXmppConfiguration']]],
  ['user',['user',['../classQXmppConfiguration.html#a50a49cee480278ddadbb6c6880a731cd',1,'QXmppConfiguration']]],
  ['username',['username',['../classQXmppRegisterIq.html#a71a483bfe920cb882d86804e67fad959',1,'QXmppRegisterIq::username()'],['../classQXmppPasswordRequest.html#a80eaf03d9905b9a9e778444d4f1a2882',1,'QXmppPasswordRequest::username()']]],
  ['usesaslauthentication',['useSASLAuthentication',['../classQXmppConfiguration.html#a60226ec21c25409f04b3f5971738e30b',1,'QXmppConfiguration']]]
];

==> qxmpp_0.7.5.orig.tar.gz: qxmpp-0.7.5/doc/html/search/all_75.js <==
var searchData=
[
  ['unavailable',['Unavailable',['../classQXmppPresence.html#a47ab8dd08436f9d7c90d2990678b5a6da6188ca67163c9045eb9568deefb9a363',1,'QXmppPresence']]],
  ['unsubscribe',['Unsubscribe',['../classQXmppPresence.html#a47ab8dd08436f9d7c90d2990678b5a6da20986f18e387f68a5fdfa0e67c44bc44',1,'QXmppPresence::Unsubscribe()'],['../classQXmppRosterManager.html#aa743c82ec16b20e1134f994487db1023',1,'QXmppRosterManager::unsubscribe()']]],
  ['unsubscribed',['Unsubscribed',['../classQXmppPresence.html#a47ab8dd08436f9d7c90d2990678b5a6da63414092d2fc4b90987f56731c150623',1,'QXmppPresence']]],
  ['updatecounter',['updateCounter',['../classQXmppLogger.html#a9dfaa287ed3dc1b37e9f0824f279bc9c',1,'QXmppLogger::updateCounter()'],['../classQXmppLoggable.html#aa309eaea9699e7fe652a400cef346ae2',1,'QXmppLoggable::updateCounter()']]],
  ['uris',['uris',['../classQXmppDataForm_1_1Media.html#a3b25e4741293aacf49e67763d6335ffa',1,'QXmppDataForm::Media']]],
  ['url',['url',['../classQXmppBookmarkUrl.html#ad4f5f12b7d3abcec0dd39b807bc574e4',1,'QXmppBookmarkUrl::url()'],['../classQXmppVCardIq.html#aece55c4dc1a59328aaa643ec7fddb1ec',1,'QXmppVCardIq::url()']]],
  ['urls',['urls',['../classQXmppBookmarkSet.html#ac670a788961da47538470df0a962417e',1,'QXmppBookmarkSet']]],
  ['usenonsaslauthentication',['useNonSASLAuthentication',['../classQXmppConfiguration.html#aa1fde10dbd102621f412e64cb047a65e',1,'QXmppConfiguration']]],
  ['user',['user',['../classQXmppConfiguration.html#a50a49cee480278ddadbb6c6880a731cd',1,'QXmppConfiguration']]],
  ['username',['username',['../classQXmppRegisterIq.html#a71a483bfe920cb882d86804e67fad959',1,'QXmppRegisterIq::username()'],['../classQXmppPasswordRequest.html#a80eaf03d9905b9a9e778444d4f1a2882',1,'QXmppPasswordRequest::username()']]],
  ['usesaslauthentication',['useSASLAuthentication',['../classQXmppConfiguration.html#a60226ec21c25409f04b3f5971738e30b',1,'QXmppConfiguration']]]
];
